@@ -15,7 +15,7 @@ from six.moves import map
 from six.moves import range
 
 from m3_gar_client.backends.m3_rest_gar.proxy.server import server
-from m3_gar_client.constants import GAR_HIERARCHY_MUN
+from m3_gar_client.constants import GAR_HIERARCHY_MUN, DEFAULT_PAGE_LIMIT
 from m3_gar_client.constants import GAR_LEVELS_PLACE
 from m3_gar_client.constants import GAR_LEVELS_STREET
 from m3_gar_client.data import AddressObject
@@ -51,6 +51,7 @@ class AddressObjectMapper(ObjectMapper):
         'formal_name': 'name',
         'official_name': 'name',
         'short_name': 'typename',
+        'type_full_name': 'type_full_name',
         'level': 'level',
         'kladr_code': 'params__CODE__value',
         'kladr_plain_code': 'params__PLAINCODE__value',
@@ -58,6 +59,7 @@ class AddressObjectMapper(ObjectMapper):
         'date_of_creation': 'startdate',
         'date_of_expiration': 'enddate',
         'full_name': 'hierarchy__mun__name_with_parents',
+        'has_children': 'hierarchy__mun__has_children',
         'region_code': 'region_code',
         'adm_parent_obj_id': 'hierarchy__adm__parentobjid__objectid',
         'adm_parent_guid': 'hierarchy__adm__parentobjid__objectguid',
@@ -112,9 +114,11 @@ class UIAddressObjectMapper(ObjectMapper):
         'objectId': 'objectguid',
         'level': 'level',
         'shortName': 'typename',
+        'typeFullName': 'type_full_name',
         'formalName': 'name',
         'postalCode': 'params__PostIndex__value',
         'fullName': 'hierarchy__mun__name_with_parents',
+        'hasChildren': 'hierarchy__mun__has_children',
     }
 
 
@@ -250,7 +254,7 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
         """
         from django.conf import settings
         # Значение PAGE_LIMIT по умолчанию 5. С большим PAGE_LIMIT можно заддосить ГАР
-        page_limit = settings.GAR.get('PAGE_LIMIT', 5)
+        page_limit = settings.GAR.get('PAGE_LIMIT', DEFAULT_PAGE_LIMIT)
 
         if page is None:
             pages = count(start=1)
@@ -440,8 +444,8 @@ class PlaceLoader(AddressObjectLoaderBase):
 
             return pages
 
-        # Значение PAGE_LIMIT по умолчанию 1. С большим PAGE_LIMIT можно заддосить ГАР
-        page_limit = settings.GAR.get('PAGE_LIMIT', 1)
+        # Значение PAGE_LIMIT по умолчанию 5. С большим PAGE_LIMIT можно заддосить ГАР
+        page_limit = settings.GAR.get('PAGE_LIMIT', DEFAULT_PAGE_LIMIT)
 
         # Нам могут передать что-то вроде "Новосибирск, Маяк". В этом случае
         # все части, кроме последней - это потенциальные фильтры по родителям
