@@ -38,8 +38,10 @@ class UIAddressObjectMapper(ObjectMapper):
         'level': 'level',
         'shortName': 'short_name',
         'formalName': 'formal_name',
+        'typeFullName': 'type_full_name',
         'postalCode': 'postal_code',
         'fullName': 'full_name',
+        'hasChildren': 'has_children',
     }
 
 
@@ -172,6 +174,7 @@ class AddressFields(BaseExtComponent):
                 'level',
                 'fullName',
                 'postalCode',
+                'hasChildren',
             ],
             store=ExtJsonStore(
                 url=self.backend.place_search_url,
@@ -233,9 +236,10 @@ class AddressFields(BaseExtComponent):
                 'objectId',
                 'level',
                 'shortName',
+                'typeFullName',
                 'postalCode',
                 'formalName',
-                'name',  # значение поля формируется как shortName + formalName
+                'name',  # значение поля формируется как typeFullName + formalName
             ],
             store=ExtJsonStore(
                 url=self.backend.street_search_url,
